@@ -4,7 +4,6 @@
 from bitbadgespy_sdk.api.accounts_api import AccountsApi
 from bitbadgespy_sdk.api.address_lists_api import AddressListsApi
 from bitbadgespy_sdk.api.applications_api import ApplicationsApi
-from bitbadgespy_sdk.api.attestations_api import AttestationsApi
 from bitbadgespy_sdk.api.badges_api import BadgesApi
 from bitbadgespy_sdk.api.claim_alerts_api import ClaimAlertsApi
 from bitbadgespy_sdk.api.claims_api import ClaimsApi
@@ -14,5 +13,5 @@ from bitbadgespy_sdk.api.miscellanous_api import MiscellanousApi
 from bitbadgespy_sdk.api.plugins_api import PluginsApi
 from bitbadgespy_sdk.api.sign_in_with_bit_badges_api import SignInWithBitBadgesApi
 from bitbadgespy_sdk.api.transactions_api import TransactionsApi
-from bitbadgespy_sdk.api.utility_listings_api import UtilityListingsApi
+from bitbadgespy_sdk.api.utility_pages_api import UtilityPagesApi
 
